api.system.components.configuration.v1.test_helpers.host package — Argus-Toolbelt 1.0 documentation

# api.system.components.configuration.v1.test_helpers.host package

## Submodules

## api.system.components.configuration.v1.test_helpers.host.add_comment module

`api.system.components.configuration.v1.test_helpers.host.add_comment.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/comment, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.host.add_comment.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/comment, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.host.add_comment.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/comment, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.host.add_comment.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/comment, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.host.create module

`api.system.components.configuration.v1.test_helpers.host.create.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.host.create.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.host.create.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.host.create.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.host.delete module

`api.system.components.configuration.v1.test_helpers.host.delete.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.host.delete.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.host.delete.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.host.delete.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.host.disable_monitoring module

`api.system.components.configuration.v1.test_helpers.host.disable_monitoring.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/disable, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.host.disable_monitoring.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/disable, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.host.disable_monitoring.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/disable, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.host.disable_monitoring.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/disable, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.host.duplicate module

`api.system.components.configuration.v1.test_helpers.host.duplicate.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/duplicate, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.host.duplicate.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/duplicate, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.host.duplicate.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/duplicate, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.host.duplicate.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/duplicate, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.host.enable_monitoring module

`api.system.components.configuration.v1.test_helpers.host.enable_monitoring.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/enable, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.host.enable_monitoring.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/enable, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.host.enable_monitoring.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/enable, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.host.enable_monitoring.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/enable, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.host.list module

`api.system.components.configuration.v1.test_helpers.host.list.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.host.list.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.host.list.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.host.list.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.host.schedule_monitoring module

`api.system.components.configuration.v1.test_helpers.host.schedule_monitoring.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/schedule, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.host.schedule_monitoring.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/schedule, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.host.schedule_monitoring.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/schedule, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.host.schedule_monitoring.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+/monitoring/schedule, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.host.search module

`api.system.components.configuration.v1.test_helpers.host.search.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/search, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.host.search.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/search, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.host.search.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/search, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.host.search.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/search, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.host.update module

`api.system.components.configuration.v1.test_helpers.host.update.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.host.update.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.host.update.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.host.update.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.host.view module

`api.system.components.configuration.v1.test_helpers.host.view.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.host.view.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.host.view.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.host.view.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/host/w+, respond with HTTP 401

## Module contents